@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2012-2021, Christopher C. Hulbert
+ * Copyright (c) 2015-2022, The matio contributors
+ * Copyright (c) 2012-2014, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,6 +45,38 @@
 /* As FC_FUNC, but for C identifiers containing underscores. */
 #undef FC_FUNC_
 
+/* Define to 1 if you have the `fseeko' function. */
+#undef HAVE_FSEEKO
+
+/* Define to 1 if you have the `ftello' function. */
+#undef HAVE_FTELLO
+
+/* Define to 1 if you have the `fseeko64' function. */
+#undef HAVE_FSEEKO64
+
+/* Define to 1 if you have the `ftello64' function. */
+#undef HAVE_FTELLO64
+
+/* Define to 1 if you have the `_fseeki64' function. */
+#if defined(_MSC_VER) && _MSC_VER >= 1400
+#define HAVE__FSEEKI64 1
+#else
+#undef HAVE__FSEEKI64
+#endif
+
+/* Define to 1 if you have the `_ftelli64' function. */
+#if defined(_MSC_VER) && _MSC_VER >= 1400
+#define HAVE__FTELLI64 1
+#else
+#undef HAVE__FTELLI64
+#endif
+
+/* Define if 64-bit file address support in 32-bit OS. */
+#undef _FILE_OFFSET_BITS
+
+/* Define if 64-bit file address support in 32-bit OS. */
+#undef _LARGEFILE64_SOURCE
+
 /* Define to 1 if you have the `asprintf' function. */
 #undef HAVE_ASPRINTF
 
@@ -238,7 +271,7 @@
 #define PACKAGE_NAME "MATIO"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "MATIO 1.5.20"
+#define PACKAGE_STRING "MATIO 1.5.22"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "matio"
@@ -247,7 +280,7 @@
 #define PACKAGE_URL "https://sourceforge.net/projects/matio"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "1.5.20"
+#define PACKAGE_VERSION "1.5.22"
 
 /* The size of `char', as computed by sizeof. */
 #define SIZEOF_CHAR 1
@@ -286,7 +319,7 @@
 #undef STDC_HEADERS
 
 /* Version number of package */
-#define VERSION "1.5.20"
+#define VERSION "1.5.22"
 
 /* Z prefix */
 #undef Z_PREFIX
